import pytest
from easy_publish import utils

def test_listdir_fullpath():
    # Test different paths and ensure utils function handles them properly
    a = utils.listdir_fullpath("/etc")
    b = utils.listdir_fullpath("~")
    c = utils.listdir_fullpath("./tests/fakenotes")
    assert len(a) > 5
    assert len(b) > 5
    assert len(c) > 2

def test_bad_listdir_fullpath():
    with pytest.raises(FileNotFoundError):
        utils.listdir_fullpath("kfjskjflkds")

def test_array_splitter():
    pass




import os
from typing import TextIO

def listdir_fullpath(directory: str) -> list:
    """
    takes a directory path and lists out all files.
    returns file names as a list.
    """
    directory = os.path.expanduser(directory)

    file_list = []
    for file in os.listdir(directory):
        absolute_file_path = os.path.join(directory, file)
        if os.path.isfile(absolute_file_path):
            file_list.append(absolute_file_path)

    return file_list

def array_splitter(file: TextIO) -> int:
    # will refactor later; works fine for now as inline
    try:
        if file.index("~") == 0:
            file.pop(0)
            return array_splitter(file)
        else:
            return file.index("~")
    except ValueError:
        if file.index("~\n") == 0:
            file.pop(0)
            return array_splitter(file)
        else:
            return file.index("~\n")



import pytest
from easy_publish import generate_posts, generate_parsed_post_list, PostParser, PostCollection


@pytest.fixture(scope="module")
def fakenotes_files():
    return ['./tests/fakenotes/note.md',
             './tests/fakenotes/other.md',
             './tests/fakenotes/other-note-two.md']

@pytest.fixture(scope="module")
def fakenotes_file():
    return './tests/fakenotes/note.md'

@pytest.fixture(scope="module")
def parsed_posts(fakenotes_files):
    parsed_posts = generate_parsed_post_list(fakenotes_files)
    return parsed_posts

def test_generate_posts():
    # incomplete
    posts = generate_posts("./tests/fakenotes")
    assert posts.__class__.__name__ == 'PostCollection'

def test_PostCollection(parsed_posts):
    # incomplete
    post_collection = PostCollection(parsed_posts)
    assert post_collection.posts.__class__.__name__ == "dict"
    assert post_collection.metadata.__class__.__name__ == "list"

def test_Metadata():
    pass

def test_PostParser(fakenotes_file):
    # incomplete
    p = PostParser(fakenotes_file)
    assert p.file == "./tests/fakenotes/note.md"
    assert p.title == "This is the fakenote"
    assert p.date == "5-23-94"
    assert p.author == "Sam Dixon"
    assert p.tags == ["first post", "item", "blogpost"]
    assert p.content
